library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity accel is port(
	clk	: in std_logic;
	accel_CLK : out std_logic;
	accel_MOSI : out std_logic;
	accel_MISO : in std_logic;
	aclSS : out std_logic;
	accel_X : out std_logic_vector(11 downto 0):=(others => '0'); -- (11) ist Vorzeichen, '1' wenn positiv.
	accel_Y : out std_logic_vector(11 downto 0):=(others => '0');
	accel_Z : out std_logic_vector(11 downto 0):=(others => '0');
	start_out : out std_logic);
end accel;

architecture Behavioral of accel is

signal divider_read: unsigned(17 downto 0):=(others => '0'); --95Hz
signal edgecounter: integer range 0 to 64:=0;
signal ADXL362_inst_adr: unsigned(15 downto 0):="0000101100001110"; -- x0B & x0E: x0B ist SPI Command für read, x0E ist Startadresse XDATA_L
signal buffer_zyx: std_logic_vector(47 downto 0):=(others => '0');

begin

process begin
	wait until rising_edge(clk);
	divider_read <= divider_read +1;
	start_out <= '0';
	accel_CLK <= '1';
	
	if divider_read(2 downto 0) = "111" and edgecounter < 64 then
		edgecounter <= edgecounter +1;
	end if;
	
	if divider_read = 8 then
		edgecounter <= 0;
	end if;
	
	if divider_read =  0 then
		aclSS <= '0';
		accel_MOSI <= '0';
		edgecounter <= 0;
	end if;
	
	if divider_read > 7 and divider_read < 528 then
		accel_CLK <= divider_read(2);
	end if;
	
	if  edgecounter < 16 then
		accel_MOSI <= ADXL362_inst_adr(15 - (edgecounter));
	end if;
	
	if edgecounter = 16 then
		accel_MOSI <= '0';
	end if;
	
	if edgecounter > 15 and edgecounter < 64 and divider_read(2 downto 0) = "100" then
		buffer_zyx(47-(edgecounter -16)) <= accel_MISO;
	end if;
	
	if divider_read = 528 then
		accel_X <= buffer_zyx(35) & std_logic_vector(unsigned(not(buffer_zyx(34 downto 32) & buffer_zyx(47 downto 40))) +1);
		accel_Y <= buffer_zyx(19) & std_logic_vector(unsigned(not(buffer_zyx(18 downto 16) & buffer_zyx(31 downto 24))) +1);
		accel_Z <= buffer_zyx(3) & std_logic_vector(unsigned(not(buffer_zyx(2 downto 0) & buffer_zyx(15 downto 8))) +1);
	end if;
	
	if divider_read = 536 then
		aclSS <= '1';
		start_out <= '1';
	end if;

end process;

end Behavioral;